/**
 * Copyright (c) 2014-2024, MindFusion LLC - Bulgaria.
 */

import java.awt.Color;
import java.awt.image.BufferedImage;
import java.io.*;

import javax.imageio.ImageIO;
import javax.swing.*;

import com.mindfusion.drawing.*;
import com.mindfusion.diagramming.*;


public class Tutorial3 extends JFrame
{
	public static void main(String[] args)
	{
		SwingUtilities.invokeLater(new Runnable() {
	        public void run() {
	          new Tutorial3();
	        }
	    });
	}

	public Tutorial3()
	{
		super("JDiagram Tutorial 3: Basic Custom Nodes");
		
		// set up the main window
		setBounds(0, 0, 800, 550);
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		setVisible(true);

		// create diagram and view
		Diagram.registerClass(OrgChartNode.class, "my:OrgChartNode", 1);
		Diagram diag = new Diagram();
		DiagramView view = new DiagramView();
		view.setDiagram(diag);

		// add scroll pane
		JScrollPane scrollPane = new JScrollPane(view);
		scrollPane.setVisible(true);
		getContentPane().add(scrollPane);

		// create first OrgChartNode
		OrgChartNode node1 = new OrgChartNode(diag);
		node1.setStroke(new Pen(Color.RED, 0.5));
		node1.setBounds(20, 10, 80, 40);
		node1.setTitle("CEO");
		node1.setFullName("John Smith");
		node1.setText("Our beloved leader.\n" +
		    "The CEO of this great corporation.");
		node1.setImage(loadImage("image1.png"));
		diag.add(node1);

		// create second OrgChartNode
		OrgChartNode node2 = new OrgChartNode(diag);
		node2.setBounds(60, 60, 80, 40);
		node2.setTitle("CIO");
		node2.setFullName("Bob Smith");
		node2.setText("The CIO of this great corporation.");
		node2.setImage(loadImage("image2.png"));
		diag.add(node2);

		// create connector
		diag.getFactory().createDiagramLink(node1, node2);
	}

	BufferedImage loadImage(String fileName)
	{
		BufferedImage image = null;
		try
		{
			image = ImageIO.read(new File(fileName));
		}
		catch (IOException e1)
		{
			e1.printStackTrace();
		}
		return image;
	}
	
	private static final long serialVersionUID = 1L;
}